==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/ResponsiveStateExitedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateExitedEventArgsDescription } from "./ResponsiveStateExitedEventArgsDescription";
/**
 * @hidden
 */
var ResponsiveStateExitedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ResponsiveStateExitedEventArgsDescriptionMetadata, _super);
    function ResponsiveStateExitedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ResponsiveStateExitedEventArgsDescriptionMetadata.b = function (a) {
        if (ResponsiveStateExitedEventArgsDescriptionMetadata.a == null) {
            ResponsiveStateExitedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ResponsiveStateExitedEventArgsDescriptionMetadata.c(ResponsiveStateExitedEventArgsDescriptionMetadata.a);
        }
        if (a.j(ResponsiveStateExitedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(ResponsiveStateExitedEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateExitedEventArgsDescriptionMetadata.c = function (a) {
    };
    ResponsiveStateExitedEventArgsDescriptionMetadata.d = function (a) {
        ResponsiveStateExitedEventArgsDescriptionMetadata.b(a);
        a.aa("ResponsiveStateExitedEventArgs", function () { return new ResponsiveStateExitedEventArgsDescription(); });
        a.z("ResponsiveStateExitedEventArgs", ResponsiveStateExitedEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateExitedEventArgsDescriptionMetadata.$t = markType(ResponsiveStateExitedEventArgsDescriptionMetadata, 'ResponsiveStateExitedEventArgsDescriptionMetadata');
    ResponsiveStateExitedEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateExitedEventArgsDescriptionMetadata;
}(Base));
export { ResponsiveStateExitedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/ResponsiveStateExitedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ResponsiveStateExitedEventArgsDescription } from "./ResponsiveStateExitedEventArgsDescription";
/**
 * @hidden
 */
var ResponsiveStateExitedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(ResponsiveStateExitedEventArgsDescriptionMetadata, _super);
    function ResponsiveStateExitedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ResponsiveStateExitedEventArgsDescriptionMetadata.b = function (a) {
        if (ResponsiveStateExitedEventArgsDescriptionMetadata.a == null) {
            ResponsiveStateExitedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ResponsiveStateExitedEventArgsDescriptionMetadata.c(ResponsiveStateExitedEventArgsDescriptionMetadata.a);
        }
        if (a.k(ResponsiveStateExitedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(ResponsiveStateExitedEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateExitedEventArgsDescriptionMetadata.c = function (a) {
    };
    ResponsiveStateExitedEventArgsDescriptionMetadata.d = function (a) {
        ResponsiveStateExitedEventArgsDescriptionMetadata.b(a);
        a.ac("ResponsiveStateExitedEventArgs", function () { return new ResponsiveStateExitedEventArgsDescription(); });
        a.ab("ResponsiveStateExitedEventArgs", ResponsiveStateExitedEventArgsDescriptionMetadata.a);
    };
    ResponsiveStateExitedEventArgsDescriptionMetadata.$t = markType(ResponsiveStateExitedEventArgsDescriptionMetadata, 'ResponsiveStateExitedEventArgsDescriptionMetadata');
    ResponsiveStateExitedEventArgsDescriptionMetadata.a = null;
    return ResponsiveStateExitedEventArgsDescriptionMetadata;
}(Base));
export { ResponsiveStateExitedEventArgsDescriptionMetadata };
